@@ -10,17 +10,20 @@ def get_otoc_hamming_distribution(J=-1.0, h=2.0, z=4, theta=0.174532925199432957
         raise ValueError("OTOCS pauli_string must be same length as n_qubits! (Use 'I' for qubits that aren't changed.)")
 
     fwd = probability_by_hamming_weight(J, h, z, theta, t, n_qubits + 1)
-    rev = probability_by_hamming_weight(-J, -h, z, -theta, t, n_qubits + 1)
+    rev = probability_by_hamming_weight(-J, -h, z, theta + np.pi, t, n_qubits + 1)
     diff_theta = rev - fwd
 
-    phi = theta - np.pi / 2
-    fwd = probability_by_hamming_weight(J, h, z, phi, t, n_qubits + 1)
-    rev = probability_by_hamming_weight(-J, -h, z, -phi, t, n_qubits + 1)
+    phi = theta + np.pi / 2
+    fwd = probability_by_hamming_weight(-h, -J, z, phi, t, n_qubits + 1)
+    rev = probability_by_hamming_weight(h, J, z, phi + np.pi, t, n_qubits + 1)
     diff_phi = rev - fwd
 
+    # Lambda (Y-axis) is at a right angle to both J and h,
+    # so there is no difference in this dimension.
+
     diff_theta *= cycles
     diff_phi *= cycles
-    diff_lam = 0.5 * (diff_theta + diff_phi)
+    # diff_lam = diff_phi
 
     n_bias = n_qubits + 1
     diff_z = np.zeros(n_bias, dtype=np.float64)
@@ -30,20 +33,13 @@ def get_otoc_hamming_distribution(J=-1.0, h=2.0, z=4, theta=0.174532925199432957
         match b:
             case 'X':
                 diff_z += diff_theta
-                diff_x += diff_lam
                 diff_y += diff_phi
             case 'Z':
-                diff_z += diff_phi
-                diff_x += diff_theta
-                diff_y += diff_lam
-            case 'Y':
-                diff_z += diff_lam
                 diff_x += diff_phi
                 diff_y += diff_theta
-
-    diff_z -= diff_z.min()
-    diff_x -= diff_x.min()
-    diff_y -= diff_y.min()
+            case 'Y':
+                diff_z += diff_theta
+                diff_x += diff_phi
 
     diff_z[0] += n_bias
     diff_x[0] += n_bias
@@ -69,7 +65,6 @@ def fix_cdf(hamming_prob):
     return cum_prob
 
 
-@njit
 def take_all(b, basis, sample):
     for i in range(len(basis)):
         if basis[i] == b:
